@@ -3,9 +3,9 @@ package com.sun.tools.javap.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "15.0.1+9" },
-            { "jdk", "15.0.1" },
-            { "release", "15.0.1" },
+            { "full", "25.0.1" },
+            { "jdk", "25.0.1" },
+            { "release", "25.0.1" },
         };
     }
 }
