@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "22";
+        "25.0.1";
 
     private static final String java_version_date =
-        "2024-03-19";
+        "2025-10-21";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,13 +49,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "22";
+        "25.0.1";
 
     private static final String VERSION_NUMBER =
-        "22";
+        "25.0.1";
 
     private static final String VERSION_SPECIFICATION =
-        "22";
+        "25";
 
     private static final String VERSION_BUILD =
         "";
@@ -70,10 +70,10 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "66.0";
+        "69.0";
 
     private static final String VENDOR =
-        "N/A";
+        "Arch Linux";
 
     private static final String VENDOR_URL =
         "https://openjdk.org/";
