@@ -330,7 +330,14 @@ public class FormatData_nus extends ListResourceBundle {
             { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DatePatterns",
+                new String[] {
+                    "EEEE d MMMM yyyy GGGG",
+                    "d MMMM yyyy GGGG",
+                    "d MMM y GGGG",
+                    "d/MM/y G",
+                }
+            },
             { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "japanese.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
