@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,145 +67,9 @@ public class CurrencyNames_or extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "AED", "AED" },
-            { "AFN", "AFN" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
-            { "ARS", "ARS" },
-            { "AWG", "AWG" },
-            { "AZN", "AZN" },
-            { "BAM", "BAM" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
-            { "BGN", "BGN" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
-            { "BND", "BND" },
-            { "BOB", "BOB" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BWP", "BWP" },
-            { "BYN", "BYN" },
-            { "BZD", "BZD" },
-            { "CDF", "CDF" },
-            { "CHF", "CHF" },
-            { "CLP", "CLP" },
-            { "CNH", "CNH" },
-            { "COP", "COP" },
-            { "CRC", "CRC" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
-            { "CZK", "CZK" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
-            { "ETB", "ETB" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
-            { "GEL", "GEL" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GTQ", "GTQ" },
-            { "GYD", "GYD" },
-            { "HNL", "HNL" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
-            { "ISK", "ISK" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
             { "JPY", "\u00a5" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MKD", "MKD" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
-            { "MRU", "MRU" },
-            { "MUR", "MUR" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
-            { "MYR", "MYR" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
-            { "NIO", "NIO" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEN", "PEN" },
-            { "PGK", "PGK" },
             { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
-            { "SDG", "SDG" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
-            { "SRD", "SRD" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
-            { "STN", "STN" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
-            { "THB", "THB" },
-            { "TJS", "TJS" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
-            { "UGX", "UGX" },
             { "USD", "$" },
-            { "UYU", "UYU" },
-            { "UZS", "UZS" },
-            { "VEF", "VEF" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
-            { "YER", "YER" },
-            { "ZAR", "ZAR" },
-            { "ZMW", "ZMW" },
             { "aed", "\u0b2f\u0b41\u0b15\u0b4d\u0b24 \u0b06\u0b30\u0b2c \u0b0f\u0b2e\u0b3f\u0b30\u0b47\u0b1f\u0b38\u0b4d \u0b26\u0b3f\u0b30\u0b39\u0b3e\u0b2e\u0b4d" },
             { "afn", "\u0b06\u0b2b\u0b17\u0b3e\u0b28 \u0b06\u0b2b\u0b17\u0b3e\u0b28\u0b3f" },
             { "all", "\u0b06\u0b32\u0b2c\u0b3e\u0b28\u0b3f\u0b5f \u0b32\u0b47\u0b15\u0b4d" },
@@ -292,6 +152,7 @@ public class CurrencyNames_or extends OpenListResourceBundle {
             { "lbp", "\u0b32\u0b47\u0b2c\u0b3e\u0b28\u0b3f\u0b1c\u0b4d \u0b2a\u0b3e\u0b09\u0b23\u0b4d\u0b21\u0b4d" },
             { "lkr", "\u0b36\u0b4d\u0b30\u0b40\u0b32\u0b19\u0b4d\u0b15\u0b3f\u0b5f \u0b30\u0b41\u0b2a\u0b3f" },
             { "lrd", "\u0b32\u0b3f\u0b2c\u0b47\u0b30\u0b40\u0b5f \u0b21\u0b32\u0b3e\u0b30\u0b4d" },
+            { "lsl", "\u0b32\u0b47\u0b38\u0b4b\u0b25\u0b4b \u0b32\u0b4b\u0b1f\u0b3f" },
             { "lyd", "\u0b32\u0b3f\u0b2c\u0b4d\u0b5f \u0b26\u0b3f\u0b28\u0b3e\u0b30\u0b4d" },
             { "mad", "\u0b2e\u0b4b\u0b30\u0b4b\u0b15\u0b40\u0b5f \u0b26\u0b3f\u0b30\u0b4d\u0b39\u0b3e\u0b2e\u0b4d" },
             { "mdl", "\u0b2e\u0b4b\u0b32\u0b21\u0b4b\u0b2d\u0b3e\u0b28\u0b4d \u0b32\u0b47\u0b5f\u0b41" },
@@ -334,7 +195,8 @@ public class CurrencyNames_or extends OpenListResourceBundle {
             { "sek", "\u0b38\u0b4d\u0b71\u0b47\u0b21\u0b3f\u0b36\u0b4d \u0b15\u0b4d\u0b30\u0b4b\u0b28\u0b3e" },
             { "sgd", "\u0b38\u0b3f\u0b19\u0b4d\u0b17\u0b3e\u0b2a\u0b41\u0b30\u0b4d \u0b21\u0b32\u0b3e\u0b30\u0b4d" },
             { "shp", "\u0b38\u0b47\u0b23\u0b4d\u0b1f\u0b4d. \u0b39\u0b47\u0b32\u0b47\u0b28\u0b3e \u0b2a\u0b3e\u0b09\u0b23\u0b4d\u0b21\u0b4d" },
-            { "sll", "\u0b38\u0b3f\u0b0f\u0b30\u0b3e \u0b32\u0b3f\u0b13\u0b28\u0b40\u0b5f \u0b32\u0b47\u0b13\u0b28\u0b4d" },
+            { "sle", "\u0b38\u0b3f\u0b0f\u0b30\u0b3e \u0b32\u0b3f\u0b13\u0b28\u0b40\u0b5f \u0b32\u0b47\u0b13\u0b28\u0b4d" },
+            { "sll", "\u0b38\u0b3f\u0b0f\u0b30\u0b3e \u0b32\u0b3f\u0b13\u0b28\u0b40\u0b5f \u0b32\u0b47\u0b13\u0b28\u0b4d (1964\u20142022)" },
             { "sos", "\u0b38\u0b4b\u0b2e\u0b3e\u0b32\u0b3f \u0b38\u0b3f\u0b32\u0b3f\u0b02" },
             { "srd", "\u0b38\u0b41\u0b30\u0b3f\u0b28\u0b3e\u0b2e\u0b3f\u0b1c\u0b4d \u0b21\u0b32\u0b3e\u0b30\u0b4d" },
             { "ssp", "\u0b26\u0b15\u0b4d\u0b37\u0b3f\u0b23 \u0b38\u0b41\u0b21\u0b3e\u0b28\u0b3f\u0b1c\u0b4d\u200d \u0b2a\u0b3e\u0b09\u0b23\u0b4d\u0b21\u0b4d" },
