@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -527,7 +527,7 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "tl", "\ud0c0\uac08\ub85c\uadf8\uc5b4" },
             { "tn", "\uce20\uc640\ub098\uc5b4" },
             { "to", "\ud1b5\uac00\uc5b4" },
-            { "tr", "\ud130\ud0a4\uc5b4" },
+            { "tr", "\ud280\ub974\ud0a4\uc608\uc5b4" },
             { "ts", "\ucd1d\uac00\uc5b4" },
             { "tt", "\ud0c0\ud0c0\ub974\uc5b4" },
             { "tw", "\ud2b8\uc704\uc5b4" },
@@ -589,6 +589,7 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "bin", "\ube44\ub2c8\uc5b4" },
             { "bkm", "\ucf64\uc5b4" },
             { "bla", "\uc2dd\uc2dc\uce74\uc5b4" },
+            { "blo", "\uc544\ub2c8\uc774\uc5b4" },
             { "bra", "\ube0c\ub77c\uc9c0\uc5b4" },
             { "brh", "\ube0c\ub77c\ud6c4\uc774\uc5b4" },
             { "brx", "\ubcf4\ub3c4\uc5b4" },
@@ -670,7 +671,6 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "glk", "\uae38\ub77c\ud0a4\uc5b4" },
             { "gmh", "\uc911\uc138 \uace0\uc9c0 \ub3c5\uc77c\uc5b4" },
             { "goh", "\uace0\ub300 \uace0\uc9c0 \ub3c5\uc77c\uc5b4" },
-            { "gom", "\uace0\uc544 \ucf58\uce78\uc5b4" },
             { "gon", "\uace4\ub514\uc5b4" },
             { "gor", "\uace0\ub860\ud0c8\ub85c\uc5b4" },
             { "got", "\uace0\ud2b8\uc5b4" },
@@ -734,14 +734,17 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "kum", "\ucfe0\ubbf9\uc5b4" },
             { "kut", "\ucfe0\ud14c\ub124\uc5b4" },
             { "kwk", "\uacfd\uc648\ub77c\uc5b4" },
+            { "kxv", "\ucfe0\ube44\uc5b4" },
             { "lad", "\ub77c\ub514\ub178\uc5b4" },
             { "lag", "\ub791\uae30\uc5b4" },
             { "lah", "\ub77c\ud55c\ub2e4\uc5b4" },
             { "lam", "\ub78c\ubc14\uc5b4" },
             { "lez", "\ub808\uc988\uae30\uc548\uc5b4" },
             { "lfn", "\ub9c1\uad6c\uc544 \ud504\ub791\uce74 \ub178\ubc14" },
+            { "lij", "\ub9ac\uad6c\ub9ac\uc544\uc5b4" },
             { "lil", "\ub9b4\ub8e8\uc5e3\uc5b4" },
             { "lkt", "\ub77c\ucf54\ud0c0\uc5b4" },
+            { "lmo", "\ub86c\ubc14\ub974\ub4dc\uc5b4" },
             { "lol", "\ubabd\uace0\uc5b4" },
             { "lou", "\ub8e8\uc774\uc9c0\uc560\ub098 \ud06c\ub9ac\uc62c\uc5b4" },
             { "loz", "\ub85c\uc9c0\uc5b4" },
@@ -872,6 +875,7 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "swb", "\ucf54\ubaa8\ub85c\uc5b4" },
             { "syc", "\uace0\uc804 \uc2dc\ub9ac\uc544\uc5b4" },
             { "syr", "\uc2dc\ub9ac\uc544\uc5b4" },
+            { "szl", "\uc2e4\ub808\uc2dc\uc544\uc5b4" },
             { "tce", "\ub0a8\ubd80 \ud22c\ud1a4\uc5b4" },
             { "tem", "\ud300\ub2c8\uc5b4" },
             { "teo", "\ud14c\uc870\uc5b4" },
@@ -903,6 +907,8 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "umb", "\uc6c0\ubd84\ub450\uc5b4" },
             { "und", "\uc54c \uc218 \uc5c6\ub294 \uc5b8\uc5b4" },
             { "vai", "\ubc14\uc774\uc5b4" },
+            { "vec", "\ubca0\ub124\uce58\uc544\uc5b4" },
+            { "vmw", "\ub9c8\ucfe0\uc640\uc5b4" },
             { "vot", "\ubcf4\ud2f1\uc5b4" },
             { "vun", "\ubd84\uc870\uc5b4" },
             { "wae", "\uc6d4\uc800\uc5b4" },
@@ -912,6 +918,7 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "wbp", "\uc648\ud53c\ub9ac\uc5b4" },
             { "wuu", "\uc6b0\uc5b4" },
             { "xal", "\uce7c\ubbf8\ud06c\uc5b4" },
+            { "xnr", "\uce89\ub9ac\uc5b4" },
             { "xog", "\uc18c\uac00\uc5b4" },
             { "yao", "\uc57c\uc624\uc871\uc5b4" },
             { "yap", "\uc58d\ud398\uc138\uc5b4" },
@@ -1226,7 +1233,6 @@ public class LocaleNames_ko extends OpenListResourceBundle {
             { "type.ca.japanese", "\uc77c\ubcf8\ub825" },
             { "type.cf.standard", "\ud45c\uc900 \ud1b5\ud654 \ud615\uc2dd" },
             { "type.co.phonetic", "\uc18c\ub9ac\ub098\ub294 \ub300\ub85c \uc815\ub82c \uc21c\uc11c" },
-            { "type.co.reformed", "\uac1c\uc815 \uc815\ub82c\uc21c" },
             { "type.co.searchjl", "\ud55c\uae00 \uc790\uc74c\uc73c\ub85c \uac80\uc0c9" },
             { "type.co.standard", "\ud45c\uc900 \uc815\ub82c \uc21c\uc11c" },
             { "type.ms.uksystem", "\uc57c\ub4dc\ud30c\uc6b4\ub4dc\ubc95" },
