@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -204,11 +204,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "Hindistan Vaxt\u0131",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "Yaponiya Standart Vaxt\u0131",
@@ -284,11 +284,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "Alyaska Standart Vaxt\u0131",
-               "",
+               "AKST",
                "Alyaska Yay Vaxt\u0131",
-               "",
+               "AKDT",
                "Alyaska Vaxt\u0131",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Amazon Standart Vaxt\u0131",
@@ -300,11 +300,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Azor Standart Vaxt\u0131",
-               "HMT",
+               "",
                "Azor Yay Vaxt\u0131",
-               "HMT",
+               "",
                "Azor Vaxt\u0131",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "Butan Vaxt\u0131",
@@ -590,9 +590,9 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "Atlantik Standart Vaxt",
                "AST",
                "Atlantik Yay Vaxt\u0131",
-               "ADT",
+               "AST",
                "Atlantik Vaxt",
-               "AT",
+               "AST",
             };
         final String[] Brasilia = new String[] {
                "Braziliya Standart Vaxt\u0131",
@@ -818,6 +818,14 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Kazakhstan = new String[] {
+               "Qazax\u0131stan vaxt\u0131",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Seychelles = new String[] {
                "Sey\u015fel Adalar\u0131 Vaxt\u0131",
                "",
@@ -956,11 +964,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "M\u0259rk\u0259zi Afrika Vaxt\u0131",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "\u015e\u0259rqi Afrika Vaxt\u0131",
@@ -1004,11 +1012,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "Q\u0259rbi Avropa Standart Vaxt\u0131",
-               "FMT",
+               "WET",
                "Q\u0259rbi Avropa Yay Vaxt\u0131",
-               "FMT",
+               "WEST",
                "Q\u0259rbi Avropa Vaxt\u0131",
-               "FMT",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "Meksika Sakit Okean Standart Vaxt\u0131",
@@ -1094,9 +1102,9 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "\u015eimali Da\u011fl\u0131q Amerika Standart Vaxt\u0131",
                "MST",
                "\u015eimali Da\u011fl\u0131q Amerika Yay Vaxt\u0131",
-               "MDT",
+               "MST",
                "\u015eimali Da\u011fl\u0131q Amerika Vaxt\u0131",
-               "MT",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "Mar\u015fal Adalar\u0131 Vaxt\u0131",
@@ -1106,14 +1114,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "\u015eimal-Q\u0259rbi Meksika Standart Vaxt\u0131",
-               "",
-               "\u015eimal-Q\u0259rbi Meksika Yay Vaxt\u0131",
-               "",
-               "\u015eimal-Q\u0259rbi Meksika Vaxt\u0131",
-               "",
-            };
         final String[] Papua_New_Guinea = new String[] {
                "Papua Yeni Qvineya Vaxt\u0131",
                "",
@@ -1140,27 +1140,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "Q\u0259rbi Avstraliya Standart Vaxt\u0131",
-               "",
+               "AWST",
                "Q\u0259rbi Avstraliya Yay Vaxt\u0131",
-               "",
+               "AWDT",
                "Q\u0259rbi Avstraliya Vaxt\u0131",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "\u015e\u0259rqi Qrenlandiya Standart Vaxt\u0131",
-               "",
-               "\u015e\u0259rqi Qrenlandiya Yay Vaxt\u0131",
-               "",
-               "\u015e\u0259rqi Qrenlandiya Vaxt\u0131",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "Q\u0259rbi Qrenlandiya Standart Vaxt\u0131",
-               "",
-               "Q\u0259rbi Qrenlandiya Yay Vaxt\u0131",
-               "",
-               "Q\u0259rbi Qrenlandiya Vaxt\u0131",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "M\u0259rk\u0259zi \u0130ndoneziya Vaxt\u0131",
@@ -1186,22 +1170,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "\u015e\u0259rqi Qazax\u0131stan Vaxt\u0131",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Kazakhstan_Western = new String[] {
-               "Q\u0259rbi Qazax\u0131stan Vaxt\u0131",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Australia_CentralWestern = new String[] {
                "M\u0259rk\u0259zi Q\u0259rbi Avstraliya Standart Vaxt\u0131",
                "",
@@ -1229,53 +1197,177 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "Qrinvi\u00e7 Orta Vaxt\u0131",
+                    "GMT",
+                    "Britaniya Yay Vaxt\u0131",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
             { "BST", Bangladesh },
             { "CAT", Africa_Central },
+            { "CET", Europe_Central },
             { "CNT", Newfoundland },
             { "CST", America_Central },
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "EST", America_Eastern },
+            { "HST", Hawaii_Aleutian },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
+            { "MET", Europe_Central },
             { "MIT", Apia },
+            { "MST", America_Mountain },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "UCT",
+                new String[] {
+                    "Koordinasiya edilmi\u015f \u00fcmumd\u00fcnya vaxt\u0131",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "VST", Indochina },
+            { "WET", Europe_Western },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "Qrinvi\u00e7 Orta Vaxt\u0131",
+                    "GMT",
+                    "\u0130rlandiya Yay Vaxt\u0131",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Zulu",
+                new String[] {
+                    "Koordinasiya edilmi\u015f \u00fcmumd\u00fcnya vaxt\u0131",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "Koordinasiya edilmi\u015f \u00fcmumd\u00fcnya vaxt\u0131",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "Qrinvi\u00e7 Orta Vaxt\u0131",
+                    "GMT",
+                    "Britaniya Yay Vaxt\u0131",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "Koordinasiya edilmi\u015f \u00fcmumd\u00fcnya vaxt\u0131",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Aqtau", Kazakhstan_Western },
+            { "Asia/Oral", Kazakhstan },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii", Hawaii_Aleutian },
+            { "Universal",
+                new String[] {
+                    "Koordinasiya edilmi\u015f \u00fcmumd\u00fcnya vaxt\u0131",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Asia/Aqtau", Kazakhstan },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
-            { "Asia/Aqtobe", Kazakhstan_Western },
-            { "Asia/Atyrau", Kazakhstan_Western },
+            { "Asia/Almaty", Kazakhstan },
+            { "Asia/Aqtobe", Kazakhstan },
+            { "Asia/Atyrau", Kazakhstan },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
@@ -1287,12 +1379,20 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1300,6 +1400,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1310,7 +1411,8 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1318,6 +1420,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
+            { "Canada/Yukon", Yukon },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1335,6 +1438,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1362,10 +1466,25 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Qostanay", Kazakhstan },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "Koordinasiya edilmi\u015f \u00fcmumd\u00fcnya vaxt\u0131",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1378,7 +1497,16 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "Qrinvi\u00e7 Orta Vaxt\u0131",
+                    "GMT",
+                    "Britaniya Yay Vaxt\u0131",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1403,9 +1531,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
@@ -1432,14 +1562,23 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
-            { "Asia/Qyzylorda", Kazakhstan_Western },
+            { "Asia/Qyzylorda", Kazakhstan },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1451,21 +1590,25 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1484,10 +1627,10 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1501,25 +1644,41 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "Qrinvi\u00e7 Orta Vaxt\u0131",
+                    "GMT",
+                    "Britaniya Yay Vaxt\u0131",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1530,9 +1689,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1543,9 +1704,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1557,6 +1720,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1567,6 +1731,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
             { "Pacific/Johnston", Hawaii_Aleutian },
@@ -1594,6 +1759,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1607,6 +1773,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1625,14 +1792,28 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "Qrinvi\u00e7 Orta Vaxt\u0131",
+                    "GMT",
+                    "Britaniya Yay Vaxt\u0131",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1650,6 +1831,8 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1660,10 +1843,11 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1678,9 +1862,12 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1699,6 +1886,8 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Kabul", "Kabil" },
             { "timezone.excity.Asia/Macau", "Makao" },
             { "timezone.excity.Asia/Seoul", "Seul" },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
@@ -1717,6 +1906,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kiev", "Kiyev" },
             { "timezone.excity.Europe/Riga", "Riqa" },
             { "timezone.excity.Europe/Rome", "Roma" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Africa/Accra", "Akkra" },
             { "timezone.excity.Africa/Cairo", "Qahir\u0259" },
             { "timezone.excity.Africa/Ceuta", "Seuta" },
@@ -1774,6 +1964,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Zurich", "S\u00fcrix" },
             { "timezone.excity.Indian/Chagos", "\u00c7aqos" },
             { "timezone.excity.Indian/Comoro", "Komoro" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Abidjan", "Abican" },
@@ -1838,12 +2029,10 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.America/Managua", "Manaqua" },
             { "timezone.excity.America/Marigot", "Mariqot" },
             { "timezone.excity.America/Moncton", "Monkton" },
-            { "timezone.excity.America/Nipigon", "Nipiqon" },
             { "timezone.excity.America/Noronha", "Noronya" },
             { "timezone.excity.America/Ojinaga", "Ocinaqa" },
             { "timezone.excity.America/Phoenix", "Feniks" },
             { "timezone.excity.America/Tijuana", "Tixuana" },
-            { "timezone.excity.Asia/Choibalsan", "\u00c7oybalsan" },
             { "timezone.excity.Asia/Phnom_Penh", "Pnom Pen" },
             { "timezone.excity.Atlantic/Azores", "Azor" },
             { "timezone.excity.Atlantic/Canary", "Kanar" },
@@ -1857,7 +2046,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Guernsey", "Gernzey" },
             { "timezone.excity.Europe/Istanbul", "\u0130stanbul" },
             { "timezone.excity.Europe/Sarajevo", "Sarayevo" },
-            { "timezone.excity.Europe/Uzhgorod", "Ujqorod" },
             { "timezone.excity.Indian/Maldives", "Maldiv" },
             { "timezone.excity.Pacific/Chatham", "\u00c7atam" },
             { "timezone.excity.Pacific/Gambier", "Qambiyer" },
@@ -1883,7 +2071,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.Atlantic/Bermuda", "Bermud adalar\u0131" },
             { "timezone.excity.Atlantic/Madeira", "Madeyra" },
             { "timezone.excity.Atlantic/Stanley", "Stenli" },
-            { "timezone.excity.Australia/Currie", "Kuriye" },
             { "timezone.excity.Australia/Darwin", "Darvin" },
             { "timezone.excity.Australia/Sydney", "Sidney" },
             { "timezone.excity.Europe/Astrakhan", "H\u0259\u015ft\u0259rxan" },
@@ -1899,7 +2086,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mauritius", "Mavriki" },
             { "timezone.excity.Pacific/Auckland", "Okl\u0259nd" },
             { "timezone.excity.Pacific/Honolulu", "Honolulu" },
-            { "timezone.excity.Pacific/Johnston", "Conston" },
             { "timezone.excity.Pacific/Pitcairn", "Pitkern" },
             { "timezone.excity.Africa/Casablanca", "Kasablanka" },
             { "timezone.excity.Africa/Libreville", "Librevil" },
@@ -1921,7 +2107,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Mawson", "Mouson" },
             { "timezone.excity.Europe/Copenhagen", "Kopenhagen" },
             { "timezone.excity.Europe/Luxembourg", "L\u00fcksemburq" },
-            { "timezone.excity.Europe/Zaporozhye", "Zaporojye" },
             { "timezone.excity.Pacific/Enderbury", "Enderb\u00f6ri" },
             { "timezone.excity.Pacific/Galapagos", "Qalapaqos" },
             { "timezone.excity.Pacific/Kwajalein", "Kvajaleyn" },
@@ -1957,13 +2142,9 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.America/El_Salvador", "Salvador" },
             { "timezone.excity.America/Los_Angeles", "Los Anceles" },
             { "timezone.excity.America/Mexico_City", "Mexiko" },
-            { "timezone.excity.America/Pangnirtung", "Panqnirtanq" },
             { "timezone.excity.America/Porto_Velho", "Porto Velyo" },
             { "timezone.excity.America/Puerto_Rico", "Puerto Riko" },
-            { "timezone.excity.America/Rainy_River", "Reyni \u00c7ay\u0131" },
             { "timezone.excity.America/Tegucigalpa", "Tequsiqalpa" },
-            { "timezone.excity.America/Thunder_Bay", "\u0130ld\u0131r\u0131m K\u00f6rf\u0259zi" },
-            { "timezone.excity.America/Yellowknife", "Yellounayf" },
             { "timezone.excity.Arctic/Longyearbyen", "Lonqyir" },
             { "timezone.excity.Atlantic/Cape_Verde", "Kape Verde" },
             { "timezone.excity.Australia/Lord_Howe", "Lord Hau" },
@@ -1978,7 +2159,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.America/Indiana/Knox", "Noks" },
             { "timezone.excity.America/Indianapolis", "\u0130ndianapolis" },
             { "timezone.excity.America/Rankin_Inlet", "Rankin Giri\u015fi" },
-            { "timezone.excity.America/Santa_Isabel", "Santa \u0130zabel" },
             { "timezone.excity.America/Scoresbysund", "Skoresbisund" },
             { "timezone.excity.Antarctica/Macquarie", "Makuari" },
             { "timezone.excity.Pacific/Bougainville", "Buqanvil" },
