@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -204,11 +204,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "Indiski cas",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "Japa\u0144ski standardny cas",
@@ -284,11 +284,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "Alaskojski standardny cas",
-               "",
+               "AKST",
                "Alaskojski l\u011b\u015bojski cas",
-               "",
+               "AKDT",
                "Alaskojski cas",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Amaconaski standardny cas",
@@ -300,11 +300,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Acorski standardny cas",
-               "HMT",
+               "",
                "Acorski l\u011b\u015bojski cas",
-               "HMT",
+               "",
                "Acorski cas",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "Bhuta\u0144ski cas",
@@ -582,9 +582,9 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "Atlantiski standardny cas",
                "AST",
                "Atlantiski l\u011b\u015bojski cas",
-               "ADT",
+               "AST",
                "Atlantiski cas",
-               "AT",
+               "AST",
             };
         final String[] Brasilia = new String[] {
                "Bras\u00edlia standardny cas",
@@ -810,6 +810,14 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Kazakhstan = new String[] {
+               "kazachiski cas",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Seychelles = new String[] {
                "Seychelski cas",
                "",
@@ -948,11 +956,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Srjej\u017aoafriski cas",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "P\u00f3dzajt\u0161noafriski cas",
@@ -1086,9 +1094,9 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "P\u00f3dpo\u0142nocnoameriski g\u00f3rski standardny cas",
                "MST",
                "P\u00f3dpo\u0142nocnoameriski g\u00f3rski l\u011b\u015bojski cas",
-               "MDT",
+               "MST",
                "P\u00f3dpo\u0142nocnoameriski g\u00f3rski cas",
-               "MT",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "cas Marshallowych kupow",
@@ -1098,14 +1106,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Mexiski d\u0142ujkowjacorny standardny cas",
-               "",
-               "Mexiski d\u0142ujkowjacorny l\u011b\u015bojski cas",
-               "",
-               "Mexiski d\u0142ujkowjacorny cas",
-               "",
-            };
         final String[] Papua_New_Guinea = new String[] {
                "Papua-Nowoginejski cas",
                "",
@@ -1132,27 +1132,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "P\u00f3dwjacornoawstralski standardny cas",
-               "",
+               "AWST",
                "P\u00f3dwjacornoawstralski l\u011b\u015bojski cas",
-               "",
+               "AWDT",
                "P\u00f3dwjacornoawstralski cas",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "P\u00f3dzajt\u0161nogr\u00f6nlandski standardny cas",
-               "",
-               "P\u00f3dzajt\u0161nogr\u00f6nlandski l\u011b\u015bojski cas",
-               "",
-               "P\u00f3dzajt\u0161nogr\u00f6nlandski cas",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "P\u00f3dwjacornogr\u00f6nlandski standardny cas",
-               "",
-               "P\u00f3dwjacornogr\u00f6nlandski l\u011b\u015bojski cas",
-               "",
-               "P\u00f3dwjacornogr\u00f6nlandski cas",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "Srjej\u017aoindoneski cas",
@@ -1178,22 +1162,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "P\u00f3dzajt\u0161nokazachski cas",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Kazakhstan_Western = new String[] {
-               "P\u00f3dwjacornokazachski cas",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Australia_CentralWestern = new String[] {
                "Srjej\u017aop\u00f3dwjacorny awstralski standardny cas",
                "",
@@ -1221,53 +1189,177 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "Greenwichski cas",
+                    "GMT",
+                    "Britiski l\u011b\u015bojski cas",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
             { "BST", Bangladesh },
             { "CAT", Africa_Central },
+            { "CET", Europe_Central },
             { "CNT", Newfoundland },
             { "CST", America_Central },
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "EST", America_Eastern },
+            { "HST", Hawaii_Aleutian },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
+            { "MET", Europe_Central },
             { "MIT", Apia },
+            { "MST", America_Mountain },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "UCT",
+                new String[] {
+                    "koordin\u011browany sw\u011btowy cas",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "VST", Indochina },
+            { "WET", Europe_Western },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "Greenwichski cas",
+                    "GMT",
+                    "Iriski l\u011b\u015bojski cas",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Zulu",
+                new String[] {
+                    "koordin\u011browany sw\u011btowy cas",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "koordin\u011browany sw\u011btowy cas",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "Greenwichski cas",
+                    "GMT",
+                    "Britiski l\u011b\u015bojski cas",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "koordin\u011browany sw\u011btowy cas",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Aqtau", Kazakhstan_Western },
+            { "Asia/Oral", Kazakhstan },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii", Hawaii_Aleutian },
+            { "Universal",
+                new String[] {
+                    "koordin\u011browany sw\u011btowy cas",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Asia/Aqtau", Kazakhstan },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
-            { "Asia/Aqtobe", Kazakhstan_Western },
-            { "Asia/Atyrau", Kazakhstan_Western },
+            { "Asia/Almaty", Kazakhstan },
+            { "Asia/Aqtobe", Kazakhstan },
+            { "Asia/Atyrau", Kazakhstan },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
@@ -1279,12 +1371,20 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1292,6 +1392,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1302,7 +1403,8 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1310,6 +1412,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
+            { "Canada/Yukon", Yukon },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1327,6 +1430,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1354,10 +1458,25 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Qostanay", Kazakhstan },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "koordin\u011browany sw\u011btowy cas",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1370,7 +1489,16 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "Greenwichski cas",
+                    "GMT",
+                    "Britiski l\u011b\u015bojski cas",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1394,9 +1522,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
@@ -1423,14 +1553,23 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
-            { "Asia/Qyzylorda", Kazakhstan_Western },
+            { "Asia/Qyzylorda", Kazakhstan },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1442,21 +1581,25 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1475,10 +1618,10 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1492,25 +1635,41 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "Greenwichski cas",
+                    "GMT",
+                    "Britiski l\u011b\u015bojski cas",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1521,9 +1680,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1534,9 +1695,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1548,6 +1711,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1558,6 +1722,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
             { "Pacific/Johnston", Hawaii_Aleutian },
@@ -1585,6 +1750,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1598,6 +1764,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1616,14 +1783,28 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "Greenwichski cas",
+                    "GMT",
+                    "Britiski l\u011b\u015bojski cas",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1641,6 +1822,8 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1651,10 +1834,11 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1669,9 +1853,12 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1683,6 +1870,8 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Indiana/Petersburg", America_Eastern },
             { "timezone.excity.Asia/Qatar", "Katar" },
             { "timezone.excity.Asia/Tokyo", "Tokio" },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
@@ -1696,6 +1885,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Etc/Unknown", "Njeznate" },
             { "timezone.excity.Europe/Kiev", "Kiew" },
             { "timezone.excity.Europe/Rome", "Rom" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Africa/Accra", "Akkra" },
             { "timezone.excity.Africa/Cairo", "Kairo" },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
@@ -1721,6 +1911,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Warsaw", "War\u0161awa" },
             { "timezone.excity.Europe/Zurich", "Z\u00fcrich" },
             { "timezone.excity.Indian/Comoro", "Komory" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Algiers", "Algier" },
@@ -1746,7 +1937,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Brussels", "Br\u00fcssel" },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
             { "timezone.excity.Europe/Chisinau", "Ki\u0161inau" },
-            { "timezone.excity.Europe/Uzhgorod", "U\u017egorod" },
             { "timezone.excity.Indian/Maldives", "Malediwy" },
             { "timezone.excity.Africa/Mogadishu", "Mogadi\u0161u" },
             { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarsk" },
@@ -1762,7 +1952,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Novokuznetsk", "Nowokuznjetsk" },
             { "timezone.excity.Europe/Copenhagen", "Kopenhagen" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
-            { "timezone.excity.Europe/Zaporozhye", "Sapori\u017eja" },
+            { "timezone.excity.Pacific/Enderbury", "Enderbury" },
             { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
             { "timezone.excity.Africa/Ouagadougou", "Wagadugu" },
             { "timezone.excity.Asia/Yekaterinburg", "Jekaterinburg" },
